@@ -41,6 +41,14 @@ test_that("remove_labels returns variables not of class('labelled') unmodified",
   expect_equal(remove_labels(var), var)
 })
 
+# to_factor --------------------------------------------------------------------
+
+test_that("to_factor preserves variable label", {
+  x <- labelled(c(1, 1, 2), c(yes = 1, no = 2))
+  var_label(x) <- "yes/no"
+  expect_equal(var_label(to_factor(x)), var_label(x))
+})
+
 
 
 
